@@ -26,10 +26,7 @@ def configuration(parent_package='', top_path=None):
     config.add_subpackage('ML')
     config.add_subpackage('search')
     config.add_subpackage('utils')
-
-    if 'sdist' not in sys.argv:
-        config.ext_modules = cythonize(config.ext_modules)
-
+    
     return config
 
 if __name__ == "__main__":
